NIRcannabis: NIRcannabis (deprecated)

NIRcannabisR Documentation

NIRcannabis (deprecated)

Description

Deprecated. NIRcannabis was renamed to proximateCannabis in proximetricsR 0.7.1, for consistency with the proxiscoutCannabis dataset. It is kept as an exact copy of proximateCannabis so that existing code keeps working, and will be removed in a future release. Please use proximateCannabis instead.

Usage

data("NIRcannabis")

Format

A data.frame containing 80 observations of four response variables, with their corresponding spectral data.

Details

See proximateCannabis for the description of the columns.

BUCHI Labortechnik AG.

See Also

proximateCannabis, proxiscoutCannabis


proximetricsR documentation built on Sept. 4, 2026, 5:08 p.m.