add_zero_cols: Adds a chosen number of columns with entries equal to zero to...

View source: R/proximate_write_helpers.R

add_zero_colsR Documentation

Adds a chosen number of columns with entries equal to zero to a matrix object

Description

Adds a chosen number of columns with entries equal to zero to a matrix object

Usage

add_zero_cols(object, n_zero_cols)

Arguments

object

matrix

n_zero_cols

an integer for the number of columns to be added

Value

the matrix with n_zero_cols zero-columns added to the left and right side of object


proximetricsR documentation built on Sept. 4, 2026, 5:08 p.m.