is_numeric_like: Test if a string can be coerced to a numeric

View source: R/cal_helpers.R

is_numeric_likeR Documentation

Test if a string can be coerced to a numeric

Description

based on the code found at # https://stackoverflow.com/a/21154566/2292993

Usage

is_numeric_like(
  x,
  na_strings = c("", ".", "NA", "na", "N/A", "n/a", "NaN", "nan")
)

Value

A logical vector indicating whether each element can be coerced to numeric.


proximetricsR documentation built on Sept. 4, 2026, 5:08 p.m.