matrix_cal_string: Converts a matrix into a string in style of .cal files

View source: R/proximate_write_helpers.R

matrix_cal_stringR Documentation

Converts a matrix into a string in style of .cal files

Description

Converts a matrix into a string in style of .cal files

Usage

matrix_cal_string(object)

Arguments

object

matrix to be converted into string

Value

character of length 1, where each row is separated by ';' and all values in each row is separated by ','


proximetricsR documentation built on Sept. 4, 2026, 5:08 p.m.