matrix_prj_string: Converts a matrix into a string in style of .prj files

View source: R/proximate_write_helpers.R

matrix_prj_stringR Documentation

Converts a matrix into a string in style of .prj files

Description

Converts a matrix into a string in style of .prj files

Usage

matrix_prj_string(object, transp = FALSE)

Arguments

object

matrix to be converted into string

transp

a logical. Should the matrix be transposed?

Value

character of length 1, where each row is separated by ⁠"\n"⁠ and all values in each row is separated by ⁠"\t"⁠


proximetricsR documentation built on Sept. 4, 2026, 5:08 p.m.