View source: R/proxiscout_read_data.R
| proxiscout_repetition_pattern | R Documentation |
Returns the pattern that can be used to identify repetitions in the sample ID of ProxiScout data files
proxiscout_repetition_pattern()
A character that can be used as a regex for identifying repetitions in ProxiScout data files
Claudio Orellano
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.