QVAL indicates how different the predicted response variable (y) in cross-validation deviates from the fitted version of y (i.e. the fitted y values obtained when all calibration observations are used to fit the model).
.calibration_statistics(
y,
fitted_y,
predicted_y_in_cv = NULL,
scaled_scores,
ncomp
)A list containing calibration statistics including residuals, predicted values, Mahalanobis distance, and Q-values.
a matrix of one column with the response variable.
a matrix with the estimated response variable for each component.
the cross-validation estimates of the response variable for every component.
a matrix of the scaled scores of the model.
a vector for each included component.
calibrate