- object
an optional object of class spectral_model. See details.
- key
a string for the key of the model. Defaults to a newly
generated key using UUIDgenerate.
- created
a string for date and time of the addition of the model
to the application. Default is the current date and time of the system.
See details for the format in which it has to be provided.
- changed
a string for date and time when the model has been changed.
Default is the current date and time of the system. See details for the format
in which it has to be provided.
- name
a vector of character strings of length 2 for the name and alias
of the property. If object is given or an object returned by this
function is passed to calibrate, defaults to the name of the
property (but not the alias). Otherwise, defaults to an empty character.
- sort_order
a numeric, indicating the order in which the properties
are shown on a ProxiMate device. Defaults to 1.
- tol_min
an optional numeric for the minimum error tolerance.
Defaults to NULL.
- tol_max
an optional numeric for the maximal error tolerance.
Defaults to NULL.
- decimal_places
a numeric for the decimal precision of the measurements
of the property. Defaults to 2.
- unit
a string for the units in which the reference values of the
property are measured. Defaults to an empty character.
- mahal_limit
a numeric for the maximum Mahalanobis distance allowed.
Defaults to 5.
- corrections
a vector of numerics of length 2 for bias and slope
corrections. Defaults to no corrections, i.e. c(0, 1).
- limit_min
an optional numeric for the lower limit of the reference
values. Defaults to NULL.
- limit_max
an optional numeric for the upper limit of the reference
values. Defaults to NULL.
- target
an optional numeric for the desired predicted reference values.
Defaults to NULL.
- wavelength_range
a string for the considered wavelength range of the
spectrum. Must be one of "Nir" (default), "Vis" or "Nir+Vis".
- predict_type
a string for the prediction type of the model. Defaults
to "Calibration".
- arguments
a vector of maximal length 4. Contains additional arguments
to be saved into the metadata. Defaults to a vector of empty characters of length 4.