View source: R/proximate_write_helpers.R
| add_zero_cols | R Documentation |
Adds a chosen number of columns with entries equal to zero to a matrix object
add_zero_cols(object, n_zero_cols)
object |
matrix |
n_zero_cols |
an integer for the number of columns to be added |
the matrix with n_zero_cols zero-columns added to the left and right
side of object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.