| fit_constructors | R Documentation |
These functions create configuration objects that specify the regression
method to be used within calibrate.
fit_plsr(ncomp, type = c("nwp", "standard", "modified"))
fit_xlsr(ncomp, type = c("nwp", "standard", "modified"), min_w = 3, max_w = 15)
ncomp |
a positive integer indicating the maximum number of PLS components to use. |
type |
a character string indicating the algorithm variant. One of
|
min_w |
a positive integer indicating the minimum window size for the
XLS algorithm. Default is |
max_w |
a positive integer indicating the maximum window size for the
XLS algorithm. Must be greater than |
There are two regression methods available:
fit_plsr)Uses PLS regression. The only parameter optimised is the number of
components (ncomp). Three algorithm variants are available via
type: "nwp", "standard", and "modified".
fit_xlsr)Uses the XLS algorithm. In addition to ncomp and type,
the window range (min_w, max_w) controls the local
smoothing applied within the algorithm.
An object of class c("fit_plsr", "fit_constructor") or
c("fit_xlsr", "fit_constructor") containing the specified parameters,
to be passed to calibrate.
Leonardo Ramirez-Lopez and Claudio Orellano
calibrate, calibrate_models
# PLS as in NIRWise PLUS
fit_plsr(ncomp = 15)
# Standard PLS with 15 components
fit_plsr(ncomp = 15, type = "standard")
# Modified PLS with 15 components
fit_plsr(ncomp = 15, type = "modified")
# XLS as in NIRWise PLUS
fit_xlsr(ncomp = 10)
# Standard XLS with custom window range
fit_xlsr(ncomp = 10, type = "standard", min_w = 5, max_w = 20)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.