View source: R/proximate_write_helpers.R
| matrix_cal_string | R Documentation |
Converts a matrix into a string in style of .cal files
matrix_cal_string(object)
object |
matrix to be converted into string |
character of length 1, where each row is separated by ';' and all values in each row is separated by ','
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.