matrix_cal_string: Converts a matrix into a string in style of .cal files
Description
Converts a matrix into a string in style of .cal files
Usage
matrix_cal_string(object)
Value
character of length 1, where each row is separated by ';' and all
values in each row is separated by ','
Arguments
- object
matrix to be converted into string