View source: R/proximate_write_helpers.R
| matrix_prj_string | R Documentation |
Converts a matrix into a string in style of .prj files
matrix_prj_string(object, transp = FALSE)
object |
matrix to be converted into string |
transp |
a logical. Should the matrix be transposed? |
character of length 1, where each row is separated by "\n"
and all values in each row is separated by "\t"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.