matrix_prj_string: Converts a matrix into a string in style of .prj files
Description
Converts a matrix into a string in style of .prj files
Usage
matrix_prj_string(object, transp = FALSE)
Value
character of length 1, where each row is separated by "\n"
and all values in each row is separated by "\t"
Arguments
- object
matrix to be converted into string
- transp
a logical. Should the matrix be transposed?