prep_snv: Standard Normal Variate constructor for spectral preprocessing
Description
Creates a preprocessing constructor for applying Standard Normal Variate
(SNV) normalisation to spectral data. The constructor is intended to be
passed to preprocess_recipe and executed via process.
Usage
prep_snv()
Arguments
Value
An object of class preprocessing to be used in
preprocess_recipe and executed by process.
Author
Leonardo Ramirez-Lopez with code from Antoine Stevens
Details
SNV normalises each spectrum row-wise by subtracting its mean and dividing
by its standard deviation: