View source: R/proximate_add2nax.R
| proximate_add2nax | R Documentation |
This function collects all the necessary data that is required prior updating a nax application.
proximate_add2nax(formulas = NULL, data, metadata_list = NULL, skip_indices_list = NULL)
formulas |
a list containing one or more objects of class
|
data |
a data.frame containing the data of the variables in
the model (as in the |
metadata_list |
a list of containing the specifications for the metadata
of each model in |
skip_indices_list |
a list of vectors of integers for the indices in the
input data to be skipped for the computation of each of the models in
|
A list mirroing the objects passed to the function.
Leonardo Ramirez-Lopez and Claudio Orellano
proximate_recalibrate_nax
calibrate,
preprocess_recipe,
fit_plsr,
fit_xlsr,
calibration_control,
calibrate_models
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.