This function collects all the necessary data that is required prior updating a nax application.
proximate_add2nax(formulas = NULL, data, metadata_list = NULL, skip_indices_list = NULL)A list mirroing the objects passed to the function.
a list containing one or more objects of class
formula where each of them represents the model to be
calibrated.
a data.frame containing the data of the variables in
the model (as in the calibrate function).
a list of containing the specifications for the metadata
of each model in formulas given in the same order. Each element in the
list should be defined as in the metadata argument of
calibrate using the
add_model_metadata function. Defaults to NULL.
a list of vectors of integers for the indices in the
input data to be skipped for the computation of each of the models in
formulas. The vectors in this list must be provided in the same order
as their corresponding counterparts in formulas. Defaults to NULL.
In case a list is passed, the list components must be filled with
numeric() for those formulas where there is no indices to be
skipped.
Leonardo Ramirez-Lopez and Claudio Orellano
proximate_recalibrate_nax
calibrate,
preprocess_recipe,
fit_plsr,
fit_xlsr,
calibration_control,
calibrate_models