View source: R/proximate_recalibrate_nax.R
| proximate_recalibrate_nax | R Documentation |
This function updates a nax file
proximate_recalibrate_nax(x,
preprocess_recipes = NULL,
methods = NULL,
control = calibration_control(seed = 1),
name,
add = NULL)
x |
an object of class |
preprocess_recipes |
an optional list with one or more objects of class
|
methods |
an optional list containing one ore more objects of class
|
control |
a |
name |
a vector length at most 2, consisting of characters for the name and alias of the application. Defaults to "Untitled". |
add |
an optional object of class |
A list of class "spectral_multimodel". See calibrate_models
function.
Leonardo Ramirez-Lopez and Claudio Orellano
proximate_add2nax
calibrate,
preprocess_recipe,
fit_plsr,
fit_xlsr,
calibration_control,
calibrate_models
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.