This function updates a nax file
proximate_recalibrate_nax(x,
preprocess_recipes = NULL,
methods = NULL,
control = calibration_control(seed = 1),
name,
add = NULL)A list of class "spectral_multimodel". See calibrate_models
function.
an object of class nax as returned by the
proximate_read_nax function.
an optional list with one or more objects of class
preprocess_recipe that are to be tested for finding the
optimal one for each model in the list passed to formulas.
an optional list containing one ore more objects of class
fit_constructor which are as returned by one of the
fit_constructors functions, indicating what type of regression method
to use along with its parameters.
a calibration_control object as returned by the
calibration_control function, indicating how some aspects of
the calibration process must be conducted (e.g. cross-validation and outlier
detection). Default is calibration_control(seed = 1). See details.
a vector length at most 2, consisting of characters for the name and alias of the application. Defaults to "Untitled".
an optional object of class nax_augment as returned by the
proximate_add2nax function.
Leonardo Ramirez-Lopez and Claudio Orellano
proximate_add2nax
calibrate,
preprocess_recipe,
fit_plsr,
fit_xlsr,
calibration_control,
calibrate_models