proxiscout_repetition_pattern: ProxiScout repetition pattern
Description
Returns the pattern that can be used to identify repetitions in the sample ID
of ProxiScout data files
Usage
proxiscout_repetition_pattern()
Value
A character that can be used as a regex for identifying repetitions
in ProxiScout data files