View source: R/proxiscout_write_model_info.R
| proxiscout_write_model_info | R Documentation |
Writes a JSON for the provided object that contains information about the model,
in the style of ProxiScout devices.
proxiscout_write_model_info(object, n_measurements = 1L, file = NULL)
object |
An object of class |
n_measurements |
An integer for the number of measurements. This value is
directly written into the JSON as both the |
file |
an optional character string with the path (including the filename)
where the JSON output should be written. If |
If file is NULL, the JSON is returned visibly, otherwise,
the JSON is written to the path specified by file and the JSON is
returned invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.