| sample_loo | R Documentation |
for internal use only! If group is provided, the sampling is done based on the groups.
sample_loo(N, group = NULL)
N |
the total number of observations. |
group |
the labels for each sample in |
a list with two matrices (hold_in and
hold_out) giving the indices of the observations in each
column. The number of columns represents the number of sampling repetitions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.