for internal use only! If group is provided, the sampling is done based on the groups.
sample_loo(N, group = NULL)a list with two matrices (hold_in and
hold_out) giving the indices of the observations in each
column. The number of columns represents the number of sampling repetitions.
the total number of observations.
the labels for each sample in y indicating the group each
observation belongs to.