| write_nad | R Documentation |
Internal function for generating a metadata file required for creating a ProxiMate application.
write_nad(object, path, application_meta, external_properties = NULL, verbose = TRUE)
object |
a list of models of class |
path |
a string for the directory in which the files will be saved. |
application_meta |
a list of class |
external_properties |
a list of external properties. More details in
|
verbose |
a logical. Should messages about the generated files be printed?
Default is |
This function takes a list of models of class spectral_model and generates
the corresponding metadata file (.nad). This file allows the ProxiMate
calibration software to import a .nax file. Thus, the main purpose of this
file is to added to the zip structure of an application file (.nax). See
proximate_write_nax for more details on how this file is used.
Note that it is crucial for all provided models to have some metadata added.
Invisibly returns NULL. Called for its side effect of
writing a .nad metadata file to path.
Claudio Orellano, Leonardo Ramirez-Lopez
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.