Internal function for generating a metadata file required for creating a ProxiMate application.
write_nad(object, path, application_meta, external_properties = NULL, verbose = TRUE)Invisibly returns NULL. Called for its side effect of
writing a .nad metadata file to path.
a list of models of class spectral_model for which the
metadata files should be generated.
a string for the directory in which the files will be saved.
a list of class application_metadata, containing
the metadata for the application. See add_application_metadata.
a list of external properties. More details in
proximate_write_nax. Defaults to NULL.
a logical. Should messages about the generated files be printed?
Default is TRUE.
Claudio Orellano, Leonardo Ramirez-Lopez
This function takes a list of models of class spectral_model and generates
the corresponding metadata file (.nad). This file allows the ProxiMate
calibration software to import a .nax file. Thus, the main purpose of this
file is to added to the zip structure of an application file (.nax). See
proximate_write_nax for more details on how this file is used.
Note that it is crucial for all provided models to have some metadata added.